'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var CodeMirror = _interopDefault(require('codemirror'));
require('codemirror/addon/runmode/runmode');

var escape = function (input) { return input
  .replace(/&/g, '&amp;')
  .replace(/"/g, '&quot;')
  .replace(/'/g, '&#39;')
  .replace(/</g, '&lt;')
  .replace(/>/g, '&gt;'); };

var index = function (string, ref) {
  if ( ref === void 0 ) ref = {};
  var mode = ref.mode;
  var tabSize = ref.tabSize; if ( tabSize === void 0 ) tabSize = 2;

  var html = '';
  var col = 0;

  CodeMirror.runMode(string, mode, function (text, style) {
    if (text === '\n') {
      html += '\n';
      col = 0;
      return
    }

    var content = '';

		// replace tabs
    for (var pos = 0; ;) {
      var idx = text.indexOf('\t', pos);
      if (idx === -1) {
        content += text.slice(pos);
        col += text.length - pos;
        break
      } else {
        col += idx - pos;
        content += text.slice(pos, idx);
        var size = tabSize - (col % tabSize);
        col += size;
        for (var i = 0; i < size; ++i) { content += ' '; }
        pos = idx + 1;
      }
    }

    if (style) {
      var className = 'cm-' + style.replace(/ +/g, 'cm-');
      content = "<span class=\"" + className + "\">" + (escape(content)) + "</span>";
    }

    html += content;
  });

  return html
};

module.exports = index;
